## Respan SDK
Light weight library for Respan type definitions and API payload preprocessing

Features:
- Definition of types, what data structure Respan expects to receive in API calls.
- Preprocessing, separating Respan-specific parameters from LLM-specific parameters
- Conversion, converting input types from Anthropic API format into OpenAI API format.

For **tracing**, please go to [Respan Tracing](https://github.com/respan-ai/respan-sdks/tree/main/python-sdks/respan-tracing) instead.